@@ -9,10 +9,17 @@ fn main() -> Result<(), Box<dyn Error>> {
     let library_path = realpath("slow5lib/include")?;
     let other_includes = realpath("slow5lib/src")?;
     let slow5_include = realpath("slow5lib/include/slow5")?;
+    let klib_include = realpath("slow5lib/src/klib")?;
 
     let mut cfg = cc::Build::new();
 
-    let mut includes = vec![library_path, streamvbyte, other_includes, slow5_include];
+    let mut includes = vec![
+        library_path,
+        streamvbyte,
+        other_includes,
+        slow5_include,
+        klib_include,
+    ];
     if let Some(include) = std::env::var_os("DEP_Z_INCLUDE") {
         includes.push(PathBuf::from(include));
     }
@@ -59,13 +66,36 @@ fn main() -> Result<(), Box<dyn Error>> {
         .header("slow5lib/src/slow5_misc.h")
         .header("slow5lib/src/slow5_idx.h")
         .header("slow5lib/src/slow5_extra.h")
+        .header("slow5lib/src/klib/ksort.h")
         .clang_arg("-Islow5lib/include")
+        
+        // slow5*.h
         .allowlist_function("slow5_.*")
-        .allowlist_type("slow5_.*")
         .allowlist_var("SLOW5_.*")
+        .allowlist_type("slow5_.*")
+        .allowlist_type("__slow5_press")
+        .allowlist_type("__va_list_tag")
+
+        // khash.h
+        .allowlist_type("kh.*")
+        .allowlist_function("kh.*")
+        .allowlist_type("k.*")
+        .allowlist_function("k.*")
+        .allowlist_type("__k.*")
+
+        // // kvec.h
+        .allowlist_type("kv.*")
+        .allowlist_function("kv.*")
+
+        // // ksort.h
+        // .allowlist_type("ks.*")
+        // .allowlist_function("ks.*")
+
         .size_t_is_usize(true)
         .rustfmt_bindings(true)
         .parse_callbacks(Box::new(bindgen::CargoCallbacks))
+        .ctypes_prefix("libc")
+        .allowlist_recursively(false)
         .generate()
         .expect("Unable to generate bindings");
 
